mhtg: minimal h11/trio glue
===========================

features
--------

- h11_, a transport agnostic standards-compliant http/1.1 implementation
- trio_, an async/await-native IO library focused on usability and correctness

.. _trio: https://github.com/python-trio/trio
.. _h11: https://github.com/python-hyper/h11
